import React, { Component, PropTypes } from 'react'
import { View, Text, TouchableOpacity, LayoutAnimation, Image, Dimensions } from 'react-native'
import styled, { ThemeProvider } from 'styled-components/native'

const SwitchWrapper = styled.View`
  background-color: ${props => props.value ? props.theme.primary : props.theme.secondary};
  width: ${props => props.theme.switchWidth};
  height: 24;
  border-radius: 12;
  padding: 2;
  position: relative;
  flex-shrink: 0;
  align-items: ${props => props.value ? 'flex-end' : 'flex-start'};
`

const SwitchBtn = styled.View`
  height: 20;
  width: 20;
  background-color: #fff;
  border-radius: 12;
`

const IconImage = styled.Image`
  height: 20;
  width: 20;
`

const Wrapper = styled.View`
  flex-direction: row;
  justify-content: space-between;
  ${props => props.mode === 'tag' && 'align-self: flex-start; margin: 0 5;'}
  border: ${props => (props.mode === 'tag') ? '1 solid ' + props.theme.primary : '0 solid #ffffff' };
  background-color: ${props => props.value && props.mode === 'tag' ? props.theme.primary : '#ffffff'};
  padding: 6 12;
  height: ${props => props.theme.height};
  border-radius: ${props => (props.theme.height + 12)/2};
`

const Label = styled.Text`
  align-self: center;
  color: ${props => props.value && props.mode === 'tag' ? '#fff' : '#000'};
  font-weight: bold;
  ${props => props === 'tag' && 'text-align: center;'};
`

const Icon = styled.View`

`

const Switch = (props) => {
  return (
    <SwitchWrapper value={props.value}>
      <SwitchBtn value={props.value}/>
    </SwitchWrapper>
  )
}

const Checkbox = (props) => {
  const icon = props.value ? require('./assets/ic_check_box_black.png') : require('./assets/ic_check_box_outline_blank_black.png')
  return <IconImage source={icon}/>
}

const Radio = (props) => {
  const icon = props.value ? require('./assets/ic_radio_button_checked.png') : require('./assets/ic_radio_button_unchecked.png')
  return <IconImage source={icon}/>
}

export default class Toggle extends Component {
  constructor(props) {
    super(props)

    this.handlePress = this.handlePress.bind(this)
    this.getComponent = this.getComponent.bind(this)
  }

  componentWillUpdate() {
    LayoutAnimation.easeInEaseOut()
  }

  handlePress() {
    this.props.onChange({
      value: !this.props.value,
      name: this.props.name
    })
  }

  getComponent() {
    const {type, value, mode} = this.props
    if(mode === 'tag') return
    else if(type === 'switch') return <Switch value={value}/>
    else if(type === 'checkbox') return <Checkbox value={value}/>
    else if(type === 'radio') return <Radio value={value}/>
  }

  render() {
    const {theme, value, label, count, mode, disabled} = this.props

    const _count = count && `(${count})`

    return (
      <ThemeProvider theme={theme}>
        <TouchableOpacity onPress={!disabled && this.handlePress} activeOpacity={0.9}>
          <Wrapper mode={mode} value={value}>
            <Label value={value} mode={mode}>{label} {_count}</Label>
            <Icon>{this.getComponent()}</Icon>
          </Wrapper>
        </TouchableOpacity>
      </ThemeProvider>
    )
  }
}

Toggle.propTypes = {
  name: PropTypes.string,
  value: PropTypes.bool.isRequired,
  mode: PropTypes.oneOf(['normal', 'tag'])
}

Toggle.defaultProps = {
  theme: {
    primary: '#6495ed',
    secondary: '#aaaaaa',
    switchWidth: 44,
    height: 34,
    width: 0
  },
  value: true,
  type: 'radio',
  mode: 'normal',
  label: 'hello'
}
